@@ -5,5 +5,6 @@ raw RGB colors of all 165 colorbrewer2.org color maps.
 
 """
 from .brewer2mpl import *
+from . import wesanderson
 
-__version__ = '1.4.dev'
+__version__ = '1.4'
